@@ -72,6 +72,7 @@
 //!     `Atomic<T>` if `T` is serializable or deserializable.
 //!
 
+#![forbid(unsafe_code)]
 #![no_std]
 
 #[cfg(test)]
@@ -162,8 +163,7 @@ pub use atomig_macro::{Atom, AtomInteger, AtomLogic};
 ///
 /// The trait can be automatically derived for two kinds of types:
 /// - `struct` types with only *one* field. That field's type has to implement
-///   `PrimitiveAtom` and is used as `Repr` type. Works with tuple structs or
-///   normal structs with named fields.
+///   `Atom`. Works with tuple structs or normal structs with one named field.
 /// - `enum` types that have a `#[repr(_)]` attribute specified and are C-like
 ///   (i.e. no variant has any fields). The primitive type specified in the
 ///   `#[repr(_)]` attribute is used as `Repr` type.
@@ -205,7 +205,7 @@ pub trait Atom {
     /// If your type also implements `AtomLogic` or `AtomInteger`, results of
     /// those operations might get passed to `unpack`. Furthermore, this method
     /// can be called by anyone. So at the very least, you have to make sure
-    /// that invalid input values do not lead to undefined behavior(e.g. memory
+    /// that invalid input values do not lead to undefined behavior (e.g. memory
     /// unsafety)!
     fn unpack(src: Self::Repr) -> Self;
 }
